#!/bin/sh
set -u
#ISSUE:36828 add nginx

nginx_exec=/usr/sbin/nginx
nginx_exec_bac=/usr/sbin/nginx.bac
nginx_dirs=(/var/lib/nginx/tmp/client_body /var/log/nginx /etc/nginx /var/lib/nginx/tmp/proxy /usr/share/nginx /usr/lib64/nginx/modules)
version=PATCH-X86-THIRD-0.0.1
upgrade_dir=/etc/cpeagent/upgrade/${version}
logrotate_dir=/etc/logrotate.d/nginx

Para=$1

function install()
{
    status=0
    user=nginx
    group=nginx

    #create group if not exists
    egrep "^$group" /etc/group &> /dev/null
    if [ $? -ne 0 ]
    then
        groupadd $group
        if [[ $? != 0 ]]; then
            exit 6
        fi
    fi

    #create user if not exists
    egrep "^$user" /etc/passwd &> /dev/null
    if [ $? -ne 0 ]; then
        useradd -M -s /sbin/nologin -g $group $user 2> /dev/null 
        if [[ $? != 0 ]]; then
            exit 6
        fi
    fi
    # cp nginx logrotate conf
    cp -f -v ${upgrade_dir}/nginx.log $logrotate_dir
    if [[ $? != 0 ]]; then
        exit 6
    fi
 
    #save old nginx exec
    if [[ -e $nginx_exec ]]; then
        mv -f $nginx_exec $nginx_exec_bac
        if [[ $? != 0 ]]; then
            exit 6
        fi
    fi
    #cp new nginx exec
    cp -f -v ${upgrade_dir}/nginx ${nginx_exec} 2> /dev/null
    if [[ $? != 0 ]]; then
        exit 6
    fi
    
    #mkdir nginx dir
    for DIR in ${nginx_dirs[*]}
    do
        if [[ ! -d $DIR ]]; then
            mkdir -p $DIR 2> /dev/null
            if [[ $? != 0 ]]; then
                exit 6
            fi
        fi
    done

    #cp nginx conf
    cp -f -v ${upgrade_dir}/conf/* /etc/nginx/
    if [[ $? != 0 ]]; then
        exit 6
    fi

    echo "nginx install, success"
}

function uninstall()
{
    echo "uninstall nginx, start!"

    diff $nginx_exec ${upgrade_dir}/nginx
    if [[ $? == 0 ]] 
    then
        rm -f $nginx_exec 2> /dev/null
    fi

    if [[ -e $nginx_exec_bac ]]; then
        mv -f -v $nginx_exec_bac $nginx_exec 2> /dev/null
    fi

    echo "uninstall nginx, success!"
}

if [ $Para == "install" ]; then
    install
elif [ $Para == "uninstall" ]; then
    uninstall
else 
    echo "not supported parameter"
    exit 7
fi
